from kraken_html.library import sections
from kraken_html.library import parts
from kraken_html.library import pages
from kraken_html.library import html_record
from kraken_html.library import form
from kraken_html.library import widgets

#from kraken_html.catalog.catalog import catalog



def get_catalog():
    return catalog()
    