from kraken_html.library.sections.pricing import pricing
from kraken_html.library.sections.hero import hero
from kraken_html.library.sections.nav_bar import nav_bar
from kraken_html.library.sections.search import search