from kraken_html.library.widgets.testimonial import *
from kraken_html.library.widgets.record import *
from kraken_html.library.widgets.records import *
from kraken_html.library.widgets.person import *
from kraken_html.library.widgets.map import *